==> rust-tabled_0.14.0.orig.tar.gz: tabled-0.14.0/examples/nested_table_3.rs <==
//! This example demonstrates creating a nested [`Table`] by instantiating a new
//! [`Table`] from a collection of other [`Tables`](Table).
//!
//! * This third nested [`Table`] example showcases the [`Table::new()`] approach.

use tabled::{
    settings::{
        object::{Cell, Segment},
        Alignment, Border, Extract, Highlight, Modify, Panel, Style,
    },
    Table, Tabled,
};

#[derive(Tabled)]
struct Contribution {
    author: &'static str,
    profile: &'static str,
}

impl Contribution {
    fn new(author: &'static str, profile: &'static str) -> Self {
        Self { author, profile }
    }
}

fn main() {
    let committers = [
        Contribution::new("kozmod", "https:/github.com/kozmod"),
        Contribution::new("IsaacCloos", "https:/github.com/IsaacCloos"),
    ];

    let issuers = [Contribution::new(
        "aharpervc",
        "https:/github.com/aharpervc",
    )];

    let committers_table = Table::new(committers)
        .with(Panel::header("Contributors"))
        .with(Modify::new(Segment::all()).with(Alignment::center()))
        .to_string();

    let issues_table = Table::new(issuers)
        .with(Panel::header("Issuers"))
        .with(Modify::new(Segment::all()).with(Alignment::center()))
        .to_string();

    let mut a_welcome_table =
        Table::new([String::from("Thank You"), committers_table, issues_table]);
    a_welcome_table
        .with(Extract::rows(1..))
        .with(Style::ascii().remove_horizontal())
        .with(Modify::new(Segment::all()).with(Alignment::center()))
        .with(Highlight::new(Cell::new(0, 0), Border::filled('*')));

    println!("{a_welcome_table}");
}

==> rust-tabled_0.18.0.orig.tar.gz: tabled-0.18.0/examples/nested_table_3.rs <==
//! This example demonstrates creating a nested [`Table`] by instantiating a new
//! [`Table`] from a collection of other [`Tables`](Table).
//!
//! * This third nested [`Table`] example showcases the [`Table::new()`] approach.

use tabled::{
    settings::{
        object::Rows,
        style::{BorderSpanCorrection, Style},
        Alignment, Extract, Highlight, Padding, Panel,
    },
    Table, Tabled,
};

#[derive(Tabled)]
struct Contribution {
    author: &'static str,
    profile: &'static str,
}

impl Contribution {
    fn new(author: &'static str, profile: &'static str) -> Self {
        Self { author, profile }
    }
}

fn main() {
    let committers = [
        Contribution::new("kozmod", "https:/github.com/kozmod"),
        Contribution::new("IsaacCloos", "https:/github.com/IsaacCloos"),
    ];

    let issuers = [Contribution::new(
        "aharpervc",
        "https:/github.com/aharpervc",
    )];

    let committers_table = Table::new(committers)
        .with(Panel::header("Contributors"))
        .with(Alignment::center())
        .with(BorderSpanCorrection)
        .to_string();

    let issues_table = Table::new(issuers)
        .with(Panel::header("Issuers"))
        .with(Alignment::center())
        .with(BorderSpanCorrection)
        .to_string();

    let mut welcome_table = Table::new([(committers_table, issues_table)]);
    welcome_table
        .with(Extract::rows(1..))
        .with(Panel::header("Thank You"))
        .with(Style::ascii().remove_horizontal())
        .modify(Rows::new(1..), Padding::new(1, 1, 1, 0))
        .with(Alignment::center())
        .with(Highlight::outline(Rows::first(), '*'));

    println!("{welcome_table}");
}
